@@ -19,6 +19,8 @@
 
 #include <Lum/Images/Loader.h>
 
+#include <iostream>
+
 #include <Lum/Private/Config.h>
 
 #ifdef HAVE_LIB_PNG
@@ -38,6 +40,7 @@
 #endif
 
 #include <Lum/Base/Path.h>
+#include <Lum/Base/String.h>
 
 #include <Lum/OS/Display.h>
 
@@ -175,6 +178,17 @@ namespace Lum {
         }
       }
 
+      for (std::list<Base::Path>::const_iterator path=applicationSearchPaths.begin();
+           path!=applicationSearchPaths.end();
+           ++path) {
+        Base::Path   p(*path);
+        std::wstring filename;
+
+        p.SetBaseName(basename);
+        std::cerr << "Cannot load '" << Lum::Base::WStringToString(basename) << "' as '" << Lum::Base::WStringToString(filename) << "'!" << std::endl;
+        filename=p.GetPath();
+      }
+
       return false;
     }
 
