@@ -88,6 +88,26 @@ namespace Lum {
         return 0;//drawsDisabled|drawsFocused|drawsActivated;
       }
 
+      void TextImage::Draw(OS::DrawInfo *draw, int x,int y)
+      {
+        Draw(draw,x,y,GetWidth(),GetHeight());
+      }
+
+      void TextImage::DrawStretched(OS::DrawInfo *draw,
+                                         int x,int y,
+                                         size_t w, size_t h)
+      {
+        Draw(draw,x,y,w,h);
+      }
+
+      void TextImage::DrawScaled(OS::DrawInfo *draw,
+                                      int x,int y,
+                                      size_t w, size_t h)
+      {
+        Draw(draw,x,y,w,h);
+      }
+
+
       void TextImage::Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h)
       {
         draw->PushFont(OS::display->GetFont());
@@ -225,6 +245,7 @@ namespace Lum {
         case Theme::imageClose:
         case Theme::imageAdd:
         case Theme::imageRemove:
+        case Theme::imageClear:
         case Theme::imageEdit:
           width=1;
           height=1;
@@ -264,6 +285,25 @@ namespace Lum {
         return 0;//drawsDisabled|drawsFocused|drawsActivated;
       }
 
+      void TextStockImage::Draw(OS::DrawInfo *draw, int x,int y)
+      {
+        Draw(draw,x,y,GetWidth(),GetHeight());
+      }
+
+      void TextStockImage::DrawStretched(OS::DrawInfo *draw,
+                                         int x,int y,
+                                         size_t w, size_t h)
+      {
+        Draw(draw,x,y,w,h);
+      }
+
+      void TextStockImage::DrawScaled(OS::DrawInfo *draw,
+                                      int x,int y,
+                                      size_t w, size_t h)
+      {
+        Draw(draw,x,y,w,h);
+      }
+
       void TextStockImage::Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h)
       {
         draw->PushFont(OS::display->GetFont());
@@ -280,6 +320,7 @@ namespace Lum {
               draw->DrawString(i,j,L"+");
               break;
             case Theme::imageRemove:
+            case Theme::imageClear:
               draw->DrawString(i,j,L"-");
               break;
             case Theme::imageEdit:
